pub struct Context { /* private fields */ }Implementations
Sourceimpl Context
impl Context
Sourcepub fn new() -> Self
pub fn new() -> Self
Generate a new context to be used by cinderblock applications.
Data layers
This methods adds a data_layer::in_memory::InMemoryDataLayer by default.
Sourcepub fn register_data_layer<DL: Debug + Send + Sync + 'static>(
&mut self,
data_layer: DL,
)
pub fn register_data_layer<DL: Debug + Send + Sync + 'static>( &mut self, data_layer: DL, )
Register a data layer instance so resources can look it up at runtime.